/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2012 by Tidalwave s.a.s. (http://tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.actor.io.filescan;

import javax.annotation.Nonnull;
import java.util.Arrays;
import java.util.List;
import java.nio.file.DirectoryStream.Filter;
import java.nio.file.Path;
import lombok.RequiredArgsConstructor;
import lombok.ToString;
import static lombok.AccessLevel.PRIVATE;

/***********************************************************************************************************************
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@RequiredArgsConstructor(access=PRIVATE) @ToString
public class FileExtensionFilter implements Filter<Path>
  {
    @Nonnull
    private final List<String> extensions;
    
    @Nonnull
    public static FileExtensionFilter withExtensions (final @Nonnull String ... args)
      {
        return new FileExtensionFilter(Arrays.asList(args));
      }

    @Override
    public boolean accept (final @Nonnull Path path) 
      {
        return path.toFile().isDirectory() || extensions.contains(getExtension(path));
      }
    
    @Nonnull
    private static String getExtension (final @Nonnull Path path)
      {
        final String name = path.getFileName().toString();
        return name.contains(".") ? name.replaceAll("^.*\\.", "") : "";
      }
  }
